"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.cardVariant = cardVariant;
exports.cardOutlineVariant = cardOutlineVariant;
exports.cardInverse = cardInverse;
exports.card = card;
exports.default = exports.defaultProps = void 0;

var _unitUtils = _interopRequireDefault(require("@bootstrap-styled/utils/lib/unitUtils"));

var _hover = require("./hover");

var _borderRadius = require("./border-radius");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var detectUnit = _unitUtils.default.detectUnit,
    rmUnit = _unitUtils.default.rmUnit;
var defaultProps = {
  '$enable-rounded': true,
  '$enable-hover-media-query': false,
  '$card-spacer-x': '1.25rem',
  '$card-spacer-y': '.75rem',
  '$card-bg': '#fff',
  '$card-border-width': '1px',
  '$card-border-color': 'rgba(0, 0, 0, 0.125)',
  '$card-border-radius': '.25rem',
  '$card-cap-bg': '#f7f7f9',
  '$card-border-radius-inner': 'calc(.25rem - 1px)',
  '$brand-primary': '#0275d8',
  '$brand-success': '#5cb85c',
  '$brand-info': '#5bc0de',
  '$brand-warning': '#f0ad4e',
  '$brand-danger': '#d9534f',
  '$btn-primary-bg': '#0275d8',
  '$btn-secondary-border': '#ccc',
  '$btn-info-bg': '#5bc0de',
  '$btn-success-bg': '#5cb85c',
  '$btn-warning-bg': '#f0ad4e',
  '$btn-danger-bg': '#d9534f',
  '$card-link-hover-color': '#fff',
  '$card-img-overlay-padding': '1.25rem'
};
exports.defaultProps = defaultProps;

function cardVariant(cardBackground, cardBorder) {
  return "\n    background-color: ".concat(cardBackground, ";\n    border-color: ").concat(cardBorder, ";\n  \n    & .card-header,\n    & .card-footer {\n      background-color: transparent;\n    }\n  ");
}

function cardOutlineVariant(cardColor) {
  return "\n    background-color: transparent;\n    border-color: ".concat(cardColor, ";\n  ");
}

function cardInverse() {
  var enableHoverMediaQuery = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$enable-hover-media-query'];
  var cardLinkHoverColor = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$card-link-hover-color'];
  return "\n    color: rgba(255,255,255,.65);\n    & .card-header,\n    & .card-footer {\n      background-color: transparent;\n      border-color: rgba(255,255,255,.2);\n    }\n    & .card-header,\n    & .card-footer,\n    & .card-title,\n    & .card-blockquote {\n      color: #fff;\n    }\n    & .card-link,\n    & .card-text,\n    & .card-subtitle,\n    & .card-blockquote .blockquote-footer {\n      color: rgba(255,255,255,.65);\n    }\n    \n    & .card-link {\n      ".concat((0, _hover.hoverFocus)(enableHoverMediaQuery, "color: ".concat(cardLinkHoverColor, ";")), "\n    }\n  ");
}

function card() {
  var $enableRounded = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$enable-rounded'];
  var $enableHoverMediaQuery = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$enable-hover-media-query'];
  var $cardSpacerY = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : defaultProps['$card-spacer-y'];
  var $cardSpacerX = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : defaultProps['$card-spacer-x'];
  var $cardBg = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : defaultProps['$card-bg'];
  var $cardBorderWidth = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : defaultProps['$card-border-width'];
  var $cardBorderColor = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : defaultProps['$card-border-color'];
  var $cardBorderRadius = arguments.length > 7 && arguments[7] !== undefined ? arguments[7] : defaultProps['$card-border-radius'];
  var $cardCapBg = arguments.length > 8 && arguments[8] !== undefined ? arguments[8] : defaultProps['$card-cap-bg'];
  var $cardBorderRadiusInner = arguments.length > 9 && arguments[9] !== undefined ? arguments[9] : defaultProps['$card-border-radius-inner'];
  var $brandPrimary = arguments.length > 10 && arguments[10] !== undefined ? arguments[10] : defaultProps['$brand-primary'];
  var $brandSuccess = arguments.length > 11 && arguments[11] !== undefined ? arguments[11] : defaultProps['$brand-success'];
  var $brandInfo = arguments.length > 12 && arguments[12] !== undefined ? arguments[12] : defaultProps['$brand-info'];
  var $brandWarning = arguments.length > 13 && arguments[13] !== undefined ? arguments[13] : defaultProps['$brand-warning'];
  var $brandDanger = arguments.length > 14 && arguments[14] !== undefined ? arguments[14] : defaultProps['$brand-danger'];
  var $btnPrimaryBg = arguments.length > 15 && arguments[15] !== undefined ? arguments[15] : defaultProps['$btn-primary-bg'];
  var $btnSecondaryBorder = arguments.length > 16 && arguments[16] !== undefined ? arguments[16] : defaultProps['$btn-secondary-border'];
  var $btnInfoBg = arguments.length > 17 && arguments[17] !== undefined ? arguments[17] : defaultProps['$btn-info-bg'];
  var $btnSuccessBg = arguments.length > 18 && arguments[18] !== undefined ? arguments[18] : defaultProps['$btn-success-bg'];
  var $btnWarningBg = arguments.length > 19 && arguments[19] !== undefined ? arguments[19] : defaultProps['$btn-warning-bg'];
  var $btnDangerBg = arguments.length > 20 && arguments[20] !== undefined ? arguments[20] : defaultProps['$btn-danger-bg'];
  var $cardLinkHoverColor = arguments.length > 21 && arguments[21] !== undefined ? arguments[21] : defaultProps['$card-link-hover-color'];
  var $cardImgOverlayPadding = arguments.length > 22 && arguments[22] !== undefined ? arguments[22] : defaultProps['$card-img-overlay-padding'];
  return "\n    & .card {\n      position: relative;\n      display: flex;\n      flex-direction: column;\n      background-color: ".concat($cardBg, ";\n      border: ").concat($cardBorderWidth, " solid ").concat($cardBorderColor, ";\n      ").concat((0, _borderRadius.borderRadius)($enableRounded, $cardBorderRadius), "\n    }\n    \n    & .card-block {\n      flex: 1 1 auto;\n\n      padding: ").concat($cardSpacerX, ";\n    }\n    \n    & .card-title {\n      margin-bottom: ").concat($cardSpacerY, ";\n    }\n    \n    & .card-subtitle {\n      margin-top: -").concat(rmUnit($cardSpacerY, detectUnit($cardSpacerY)) / 2 + detectUnit($cardSpacerY), ";\n      margin-bottom: 0;\n    }\n    \n    & .card-text:last-child {\n      margin-bottom: 0;\n    }\n   \n    & .card-link {\n      ").concat((0, _hover.hover)('text-decoration: none;'), "\n    \n      + .card-link {\n        margin-left: ").concat($cardSpacerX, ";\n      }\n    }\n    \n    & .card{\n      > .list-group:first-child {\n        .list-group-item:first-child {\n          ").concat((0, _borderRadius.borderTopRadius)($enableRounded, $cardBorderRadius), "\n        }\n      }\n    \n      > .list-group:last-child {\n        .list-group-item:last-child {\n          ").concat((0, _borderRadius.borderBottomRadius)($enableRounded, $cardBorderRadius), "\n        }\n      }\n    }\n    \n    & .card-header {\n      padding: ").concat($cardSpacerY, " ").concat($cardSpacerX, ";\n      margin-bottom: 0;\n      background-color: ").concat($cardCapBg, ";\n      border-bottom: ").concat($cardBorderWidth, " solid ").concat($cardBorderColor, ";\n    \n      &:first-child {\n        ").concat((0, _borderRadius.borderRadius)($enableRounded, $cardBorderRadiusInner, $cardBorderRadiusInner, '0', '0'), "\n      }\n    }\n    \n    & .card-footer {\n      padding: ").concat($cardSpacerY, " ").concat($cardSpacerX, ";\n      background-color: ").concat($cardCapBg, ";\n      border-top: ").concat($cardBorderWidth, " solid ").concat($cardBorderColor, ";\n    \n      &:last-child {\n        ").concat((0, _borderRadius.borderRadius)($enableRounded, '0', '0', $cardBorderRadiusInner, $cardBorderRadiusInner), "\n      }\n    }\n\n    & .card-header-tabs {\n      margin-right: -").concat(rmUnit($cardSpacerX, detectUnit($cardSpacerX)) / 2 + detectUnit($cardSpacerX), ";\n      margin-bottom: -").concat($cardSpacerY, ";\n      margin-left: -").concat(rmUnit($cardSpacerX, detectUnit($cardSpacerX)) / 2 + detectUnit($cardSpacerX), ";\n      border-bottom: 0;\n    }\n    \n    & .card-header-pills {\n      margin-right: -").concat(rmUnit($cardSpacerX, detectUnit($cardSpacerX)) / 2 + detectUnit($cardSpacerX), ";\n      margin-left: -").concat(rmUnit($cardSpacerX, detectUnit($cardSpacerX)) / 2 + detectUnit($cardSpacerX), ";\n    }\n    \n    & .card-primary {\n      ").concat(cardVariant($brandPrimary, $brandPrimary), "\n    }\n    & .card-success {\n      ").concat(cardVariant($brandSuccess, $brandSuccess), "\n    }\n    & .card-info {\n      ").concat(cardVariant($brandInfo, $brandInfo), "\n    }\n    & .card-warning {\n      ").concat(cardVariant($brandWarning, $brandWarning), "\n    }\n    & .card-danger {\n      ").concat(cardVariant($brandDanger, $brandDanger), "\n    }\n    \n    & .card-outline-primary {\n      ").concat(cardOutlineVariant($btnPrimaryBg), "\n    }\n    & .card-outline-secondary {\n      ").concat(cardOutlineVariant($btnSecondaryBorder), "\n    }\n    & .card-outline-info {\n      ").concat(cardOutlineVariant($btnInfoBg), "\n    }\n    & .card-outline-success {\n      ").concat(cardOutlineVariant($btnSuccessBg), "\n    }\n    & .card-outline-warning {\n      ").concat(cardOutlineVariant($btnWarningBg), "\n    }\n    & .card-outline-danger {\n      ").concat(cardOutlineVariant($btnDangerBg), "\n    }\n        \n    & .card-inverse {\n      ").concat(cardInverse($enableHoverMediaQuery, $cardLinkHoverColor), "\n    }\n\n    & .card-blockquote {\n      padding: 0;\n      margin-bottom: 0;\n      border-left: 0;\n    }\n    \n    & .card-img {\n      ").concat((0, _borderRadius.borderRadius)($enableRounded, $cardBorderRadiusInner), "\n    }\n    \n    & .card-img-overlay {\n      position: absolute;\n      top: 0;\n      right: 0;\n      bottom: 0;\n      left: 0;\n      padding: ").concat($cardImgOverlayPadding, ";\n    }\n\n    & .card-img-top {\n      ").concat((0, _borderRadius.borderTopRadius)($enableRounded, $cardBorderRadiusInner), "\n    }\n    \n    & .card-img-bottom {\n      ").concat((0, _borderRadius.borderBottomRadius)($enableRounded, $cardBorderRadiusInner), "\n    }\n  ");
}

var _default = {
  defaultProps: defaultProps,
  cardVariant: cardVariant,
  cardOutlineVariant: cardOutlineVariant,
  cardInverse: cardInverse,
  card: card
};
exports.default = _default;