"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.navbar = navbar;
exports.default = exports.defaultProps = void 0;

var _hover = require("./hover");

var _breakpoints = require("./breakpoints");

var _borderRadius = require("./border-radius");

var _navbarToggleable = require("./navbar-toggleable");

var defaultProps = {
  '$grid-breakpoints': {
    xs: '0',
    sm: '576px',
    md: '768px',
    lg: '992px',
    xl: '1200px'
  },
  '$enable-rounded': true,
  '$enable-hover-media-query': false,
  '$navbar-padding-y': '0.5rem',
  '$navbar-padding-x': '1rem',
  '$zindex-navbar': '1000',
  '$zindex-navbar-fixed': '1030',
  '$zindex-navbar-sticky': '1030',
  '$navbar-brand-padding-y': '.25rem',
  '$font-size-lg': '1.25rem',
  '$navbar-divider-padding-y': '.425rem',
  '$navbar-toggler-padding-y': '.5rem',
  '$navbar-toggler-padding-x': '.75rem',
  '$navbar-toggler-font-size': '1.25rem',
  '$border-width': '1px',
  '$navbar-toggler-border-radius': '.25rem',
  '$navbar-light-active-color': 'rgba(0,0,0,.9)',
  '$navbar-light-color': 'rgba(0,0,0,.5)',
  '$navbar-light-hover-color': 'rgba(0,0,0,.7)',
  '$navbar-light-toggler-border': 'rgba(0,0,0,.1)',
  '$navbar-light-toggler-bg': 'url(\'data:image/svg+xml;charset=utf8,%3Csvg viewBox="0 0 30 30" xmlns="http://www.w3.org/2000/svg"%3E%3Cpath stroke="rgba(0,0,0,.5)" stroke-width="2" stroke-linecap="round" stroke-miterlimit="10" d="M4 7h22M4 15h22M4 23h22"/%3E%3C/svg%3E\')',
  '$navbar-light-disabled-color': 'rgba(0, 0, 0, 0.3)',
  '$navbar-inverse-active-color': 'rgba(255,255,255,1)',
  '$navbar-inverse-color': 'rgba(255,255,255,.5)',
  '$navbar-inverse-hover-color': 'rgba(255,255,255,.75)',
  '$navbar-inverse-toggler-border': 'rgba(255,255,255,.1)',
  '$navbar-inverse-toggler-bg': 'url(\'data:image/svg+xml;charset=utf8,%3Csvg viewBox="0 0 30 30" xmlns="http://www.w3.org/2000/svg"%3E%3Cpath stroke="rgba(255,255,255,.5)" stroke-width="2" stroke-linecap="round" stroke-miterlimit="10" d="M4 7h22M4 15h22M4 23h22"/%3E%3C/svg%3E\')',
  '$navbar-inverse-disabled-color': 'rgba(255, 255, 255, 0.25)'
};
exports.defaultProps = defaultProps;

function navbar() {
  var $gridBreakpoints = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$grid-breakpoints'];
  var $enableRounded = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$enable-rounded'];
  var $enableHoverMediaQuery = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : defaultProps['$enable-hover-media-query'];
  var $navbarPaddingY = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : defaultProps['$navbar-padding-y'];
  var $navbarPaddingX = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : defaultProps['$navbar-padding-x'];
  var $zindexNavbar = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : defaultProps['$zindex-navbar'];
  var $zindexNavbarFixed = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : defaultProps['$zindex-navbar-fixed'];
  var $zindexNavbarSticky = arguments.length > 7 && arguments[7] !== undefined ? arguments[7] : defaultProps['$zindex-navbar-sticky'];
  var $navbarBrandPaddingY = arguments.length > 8 && arguments[8] !== undefined ? arguments[8] : defaultProps['$navbar-brand-padding-y'];
  var $fontSizeLg = arguments.length > 9 && arguments[9] !== undefined ? arguments[9] : defaultProps['$font-size-lg'];
  var $navbarDividerPaddingY = arguments.length > 10 && arguments[10] !== undefined ? arguments[10] : defaultProps['$navbar-divider-padding-y'];
  var $navbarTogglerPaddingY = arguments.length > 11 && arguments[11] !== undefined ? arguments[11] : defaultProps['$navbar-toggler-padding-y'];
  var $navbarTogglerPaddingX = arguments.length > 12 && arguments[12] !== undefined ? arguments[12] : defaultProps['$navbar-toggler-padding-x'];
  var $navbarTogglerFontSize = arguments.length > 13 && arguments[13] !== undefined ? arguments[13] : defaultProps['$navbar-toggler-font-size'];
  var $borderWidth = arguments.length > 14 && arguments[14] !== undefined ? arguments[14] : defaultProps['$border-width'];
  var $navbarTogglerBorderRadius = arguments.length > 15 && arguments[15] !== undefined ? arguments[15] : defaultProps['$navbar-toggler-border-radius'];
  var $navbarLightActiveColor = arguments.length > 16 && arguments[16] !== undefined ? arguments[16] : defaultProps['$navbar-light-active-color'];
  var $navbarLightColor = arguments.length > 17 && arguments[17] !== undefined ? arguments[17] : defaultProps['$navbar-light-color'];
  var $navbarLightHoverColor = arguments.length > 18 && arguments[18] !== undefined ? arguments[18] : defaultProps['$navbar-light-hover-color'];
  var $navbarLightTogglerBorder = arguments.length > 19 && arguments[19] !== undefined ? arguments[19] : defaultProps['$navbar-light-toggler-border'];
  var $navbarLightDisabledColor = arguments.length > 20 && arguments[20] !== undefined ? arguments[20] : defaultProps['$navbar-light-disabled-color'];
  var $navbarLightTogglerBg = arguments.length > 21 && arguments[21] !== undefined ? arguments[21] : defaultProps['$navbar-light-toggler-bg'];
  var $navbarInverseActiveColor = arguments.length > 22 && arguments[22] !== undefined ? arguments[22] : defaultProps['$navbar-inverse-active-color'];
  var $navbarInverseColor = arguments.length > 23 && arguments[23] !== undefined ? arguments[23] : defaultProps['$navbar-inverse-color'];
  var $navbarInverseHoverColor = arguments.length > 24 && arguments[24] !== undefined ? arguments[24] : defaultProps['$navbar-inverse-hover-color'];
  var $navbarInverseTogglerBorder = arguments.length > 25 && arguments[25] !== undefined ? arguments[25] : defaultProps['$navbar-inverse-toggler-border'];
  var $navbarInverseTogglerBg = arguments.length > 26 && arguments[26] !== undefined ? arguments[26] : defaultProps['$navbar-inverse-toggler-bg'];
  var $navbarInverseDisabledColor = arguments.length > 27 && arguments[27] !== undefined ? arguments[27] : defaultProps['$navbar-inverse-disabled-color'];
  return "\n    /* Wrapper and base class\n\n     Provide a static navbar from which we expand to create full-width, fixed, and\n     other navbar variations.\n    */\n\n    &.navbar {\n      position: relative;\n      display: flex;\n      flex-direction: column;\n      padding: ".concat($navbarPaddingY, " ").concat($navbarPaddingX, ";\n    }\n    \n    /*\n     Brand/project name\n    */\n\n    & .navbar-brand {\n      display: inline-block;\n      padding-top: ").concat($navbarBrandPaddingY, ";\n      padding-bottom: ").concat($navbarBrandPaddingY, ";\n      margin-right: ").concat($navbarPaddingX, ";\n      font-size: ").concat($fontSizeLg, ";\n      line-height: inherit;\n      white-space: nowrap;\n      ").concat((0, _hover.hoverFocus)($enableHoverMediaQuery, 'text-decoration: none;'), "\n    }\n    \n    /* Navigation\n\n     Custom navbar navigation built on the base .nav styles.\n    */\n\n    &.navbar-nav,\n    & .navbar-nav {\n      display: flex;\n      flex-direction: column; /* cannot use inherit to get the .navbars value */\n      padding-left: 0;\n      margin-bottom: 0;\n      list-style: none;\n    \n      .nav-link {\n        padding-right: 0;\n        padding-left: 0;\n      }\n    }\n    \n    /* Navbar text  */\n\n    & .navbar-text {\n      display: inline-block;\n      padding-top:    .425rem;\n      padding-bottom: .425rem;\n    }\n\n\n    /* Navbar toggle\n\n     Custom button for toggling the .navbar-collapse, powered by the collapse\n     Bootstrap JavaScript plugin.\n    */\n\n    & .navbar-toggler {\n      align-self: flex-start; \n      padding: ").concat($navbarTogglerPaddingY, " ").concat($navbarTogglerPaddingX, ";\n      font-size: ").concat($navbarTogglerFontSize, ";\n      line-height: 1;\n      background: transparent;\n      border: ").concat($borderWidth, " solid transparent;\n      ").concat((0, _borderRadius.borderRadius)($enableRounded, $navbarTogglerBorderRadius), "\n      ").concat((0, _hover.hoverFocus)($enableHoverMediaQuery, 'text-decoration: none;'), "\n    }\n    \n    /* Keep as a separate element so folks can easily override it with another icon or image file as needed. */\n    & .navbar-toggler-icon {\n      display: inline-block;\n      width: 1.5em;\n      height: 1.5em;\n      vertical-align: middle;\n      content: \"\";\n      background: no-repeat center center;\n      background-size: 100% 100%;\n    }\n    \n    /* Use position on the toggler to prevent it from being auto placed as a flex item and allow easy placement. */\n    & .navbar-toggler-left {\n      position: absolute;\n      left: ").concat($navbarPaddingX, ";\n    }\n    & .navbar-toggler-right {\n      position: absolute;\n      right: ").concat($navbarPaddingX, ";\n    }\n\n    /* Dark links against a light background */\n    &.navbar-light {\n      .navbar-brand,\n      .navbar-toggler {\n        color: ").concat($navbarLightActiveColor, ";\n\n        ").concat((0, _hover.hoverFocus)($enableHoverMediaQuery, "color: ".concat($navbarLightActiveColor, ";")), "\n      }\n\n      .navbar-nav {\n        .nav-link {\n          color: ").concat($navbarLightColor, ";\n          ").concat((0, _hover.hoverFocus)($enableHoverMediaQuery, "color: ".concat($navbarLightHoverColor, ";")), "\n          &.disabled {\n            color: ").concat($navbarLightDisabledColor, ";\n          }\n        }\n\n        .open > .nav-link,\n        .active > .nav-link,\n        .nav-link.open,\n        .nav-link.active {\n          color: ").concat($navbarLightActiveColor, ";\n        }\n      }\n\n      .navbar-toggler {\n        border-color: ").concat($navbarLightTogglerBorder, ";\n      }\n      .navbar-toggler-icon {\n        background-image: ").concat($navbarLightTogglerBg, ";\n      }\n  \n      .navbar-text {\n        color: ").concat($navbarLightColor, ";\n      }\n    }\n      \n\n    /* White links against a dark background */\n    &.navbar-inverse {\n      .navbar-brand,\n      .navbar-toggler {\n        color: ").concat($navbarInverseActiveColor, ";\n        ").concat((0, _hover.hoverFocus)($enableHoverMediaQuery, "color: ".concat($navbarInverseActiveColor, ";")), "\n      }\n\n      .navbar-nav {\n        .nav-link {\n          color: ").concat($navbarInverseColor, ";\n          ").concat((0, _hover.hoverFocus)($enableHoverMediaQuery, "color: ".concat($navbarInverseHoverColor, ";")), "\n          &.disabled {\n            color: ").concat($navbarInverseDisabledColor, ";\n          }\n        }\n\n        .open > .nav-link,\n        .active > .nav-link,\n        .nav-link.open,\n        .nav-link.active {\n          color: ").concat($navbarInverseActiveColor, ";\n        }\n      }\n\n      .navbar-toggler {\n        border-color: ").concat($navbarInverseTogglerBorder, ";\n      }\n      \n      .navbar-toggler-icon {\n        background-image: ").concat($navbarInverseTogglerBg, ";\n      }\n    \n      .navbar-text {\n        color: ").concat($navbarInverseColor, ";\n      }\n    }\n    \n\n    ").concat((0, _navbarToggleable.navbarToggleable)($gridBreakpoints), "\n    \n    /* DELETED IN LATEST BOOTSTRAP VERSINO */\n    \n    /* Navbar alignment options\n\n     Display the navbar across the entirety of the page or fixed it to the top or\n     bottom of the page.\n    */\n\n    /* A static, full width modifier with no rounded corners. */\n    &.navbar-full {\n      z-index: ").concat($zindexNavbar, ";\n      ").concat((0, _breakpoints.mediaBreakpointUp)('sm', $gridBreakpoints, (0, _borderRadius.borderRadius)($enableRounded, '0')), "\n    }\n\n      /* Fix the top/bottom navbars when screen real estate supports it */\n    &.navbar-fixed-top,\n    &.navbar-fixed-bottom {\n      position: fixed;\n      right: 0;\n      left: 0;\n      z-index: ").concat($zindexNavbarFixed, ";\n      /*  Undo the rounded corners */\n      ").concat((0, _breakpoints.mediaBreakpointUp)('sm', $gridBreakpoints, (0, _borderRadius.borderRadius)($enableRounded, '0')), "\n    }\n\n    &.navbar-fixed-top {\n      top: 0;\n    }\n\n    &.navbar-fixed-bottom {\n      bottom: 0;\n    }\n\n    /* position sticky does not seem to be working AJT*/\n\n    &.navbar-sticky-top {\n      position: sticky;\n      top: 0;\n      z-index: ").concat($zindexNavbarSticky, ";\n      width: 100%;\n\n        /*  Undo the rounded corners */\n      ").concat((0, _breakpoints.mediaBreakpointUp)('sm', $gridBreakpoints, (0, _borderRadius.borderRadius)($enableRounded, '0')), "\n    }\n\n    & .navbar-divider {\n      float: left;\n      width: ").concat($borderWidth, ";\n      padding-top: ").concat($navbarDividerPaddingY, ";\n      padding-bottom: ").concat($navbarDividerPaddingY, ";\n      margin-right: ").concat($navbarPaddingX, ";\n      margin-left:  ").concat($navbarPaddingX, ";\n      overflow: hidden;\n\n      &::before {\n        content: '\\00a0';\n      }\n    }\n  ");
}

var _default = {
  defaultProps: defaultProps,
  navbar: navbar
};
exports.default = _default;